PathButton — pyqtgraph 0.11.0rc0 documentation

# PathButton

class `pyqtgraph.` `PathButton`(parent=None, path=None, pen='default', brush=None, size=(30, 30), margin=7)

  Simple PushButton extension that paints a QPainterPath centered on its face.

  `__init__`(parent=None, path=None, pen='default', brush=None, size=(30, 30), margin=7)

    Initialize self. See help(type(self)) for accurate signature.

  `paintEvent`(self, arg__1: PySide2.QtGui.QPaintEvent)